package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseEmployeeInfo;

/**
 * 职员基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-21
 */
public interface BaseEmployeeInfoMapper 
{
    /**
     * 查询职员基础信息
     * 
     * @param objid 职员基础信息ID
     * @return 职员基础信息
     */
    public BaseEmployeeInfo selectBaseEmployeeInfoById(Long objid);

    /**
     * 查询职员基础信息列表
     * 
     * @param baseEmployeeInfo 职员基础信息
     * @return 职员基础信息集合
     */
    public List<BaseEmployeeInfo> selectBaseEmployeeInfoList(BaseEmployeeInfo baseEmployeeInfo);

    /**
     * 新增职员基础信息
     * 
     * @param baseEmployeeInfo 职员基础信息
     * @return 结果
     */
    public int insertBaseEmployeeInfo(BaseEmployeeInfo baseEmployeeInfo);

    /**
     * 修改职员基础信息
     * 
     * @param baseEmployeeInfo 职员基础信息
     * @return 结果
     */
    public int updateBaseEmployeeInfo(BaseEmployeeInfo baseEmployeeInfo);

    /**
     * 删除职员基础信息
     * 
     * @param objid 职员基础信息ID
     * @return 结果
     */
    public int deleteBaseEmployeeInfoById(Long objid);

    /**
     * 批量删除职员基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseEmployeeInfoByIds(String[] objids);
}
